==> eztrace_0.7-2.orig.tar.gz: eztrace-0.7-2/src/modules/mpi/mpi_f.f90 <==
subroutine MPI_COMM_SPAWN(CMD, ARGV, M, I, R, C, INTERCOMM, A, E)
call MPIF_COMM_SPAWN(CMD, ARGV, M, I, R, C, INTERCOMM, A, E)
return
end

subroutine MPI_INIT(error)
call MPIF_INIT(error)
return
end

subroutine MPI_Init_thread(REQUIRED, PROVIDED, IERROR)
call MPIF_Init_thread(REQUIRED, PROVIDED, IERROR)
return
end

subroutine MPI_Finalize(IERROR)
call MPIF_Finalize(IERROR)
return
end

subroutine MPI_Barrier(COMM, IERROR)
call MPIF_Barrier(COMM, IERROR)
return
end

subroutine MPI_Comm_size(COMM, SIZE, IERROR)
call MPIF_Comm_size(COMM, SIZE, IERROR)
return
end

subroutine MPI_Comm_rank(COMM, RANK, IERROR)
call MPIF_Comm_rank(COMM, RANK, IERROR)
return
end

subroutine MPI_Send(BUF, COUNT, DATATYPE, DEST, TAG, COMM, IERROR)
call MPIF_Send(BUF, COUNT, DATATYPE, DEST, TAG, COMM, IERROR)
return
end

subroutine MPI_Recv(BUF, COUNT, D, SRC, TAG, COMM, STATUS, IERROR)
call MPIF_Recv(BUF, COUNT, D, SRC, TAG, COMM, STATUS, IERROR)
return
end

subroutine MPI_Sendecv(SBUF, SCOUNT, STYPE, DST, STAG, RBUF, RCOUNT, RTYPE, SRC, RTAG, COMM, STATUS, ERROR)
call MPIF_Sendrecv(SBUF, SCOUNT, STYPE, DST, STAG, RBUF, RCOUNT, RTYPE, SRC, RTAG, COMM, STATUS, ERROR)
return
end

subroutine MPI_Sendecv_replace(BUF, COUNT, TYPE, DST, STAG, SRC, RTAG, COMM, STATUS, ERROR)
call MPIF_Sendrecv_replace(BUF, COUNT, TYPE, DST, STAG, SRC, RTAG, COMM, STATUS, ERROR)
return
end

subroutine MPI_Bsend(BUF, COUNT,DATATYPE, DEST, TAG, COMM, IERROR)
call MPIF_Bsend(BUF, COUNT,DATATYPE, DEST, TAG, COMM, IERROR)
return
end

subroutine MPI_Ssend(BUF, COUNT, D, DEST, TAG, COMM, IERROR)
call MPIF_Ssend(BUF, COUNT, D, DEST, TAG, COMM, IERROR)
return
end

subroutine MPI_Rsend(BUF, COUNT, D, DEST, TAG, COMM, IERROR)
call MPIF_Rsend(BUF, COUNT, D, DEST, TAG, COMM, IERROR)
return
end

subroutine MPI_Isend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
call MPIF_Isend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Ibsend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
call MPIF_Ibsend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Issend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
call MPIF_Issend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Irsend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
call MPIF_Irsend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Irecv(B, CNT, D, SRC, TAG, COMM, REQ, IERROR)
call MPIF_Irecv(B, CNT, D, SRC, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Wait(REQUEST, STATUS, IERROR)
call MPIF_Wait(REQUEST, STATUS, IERROR)
return
end

subroutine MPI_WAITALL(COUNT, R, S, IERROR)
call MPIF_Waitall(COUNT, R, S, IERROR)
return
end

subroutine MPI_WAITANY(COUNT, R, S, INDEX, IERROR)
call MPIF_Waitany(COUNT, R, S, INDEX, IERROR)
return
end

subroutine MPI_WAITSOME(IC, R, OC, INDEX, S, IERROR)
call MPIF_Waitsome(IC, R, OC, INDEX, S, IERROR)
return
end

subroutine MPI_TESTSOME(IC, R, OC, INDEX, S, IERROR)
call MPIF_Testsome(IC, R, OC, INDEX, S, IERROR)
return
end


subroutine MPI_PROBE(S, T, C, STAT, IERROR)
call MPIF_PROBE(S, T, C, STAT, IERROR)
return
end

subroutine MPI_IPROBE(S, T, C, FLAG, STAT, IERROR)
call MPIF_IPROBE(S, T, C, FLAG, STAT, IERROR)
return
end


subroutine MPI_Test(REQUEST, FLAG, STATUS, IERROR)
call MPIF_Test(REQUEST, FLAG, STATUS, IERROR)
return
end

subroutine MPI_Testall(C, REQUEST, INDEX, STATUS, IERROR)
call MPIF_Testall(C, REQUEST, INDEX, STATUS, IERROR)
return
end

subroutine MPI_Testany(C, REQUEST, INDEX, F, STATUS, IERROR)
call MPIF_Testany(C, REQUEST, INDEX, F, STATUS, IERROR)
return
end

subroutine MPI_Get(O_A, O_C, O_D, T_R, T_DS, T_C, T_D, W, ERROR)
call MPIF_Get(O_A, O_C, O_D, T_R, T_DS, T_C, T_D, W, ERROR)
return
end

subroutine MPI_Put(O_A, O_C, O_D, T_R, T_DS, T_C, T_D, W, ERROR)
call MPIF_Put(O_A, O_C, O_D, T_R, T_DS, T_C, T_D, W, ERROR)
return
end

subroutine MPI_BCast(BUFFER, COUNT, DATATYPE, ROOT, COMM, IERROR)
call MPIF_BCast(BUFFER, COUNT, DATATYPE, ROOT, COMM, IERROR)
return
end

subroutine MPI_Gather(SBUF,SCNT,STYPE,RBUF,RCNT, RTYPE, R, C, E)
call MPIF_Gather(SBUF, SCNT, STYPE, RBUF, RCNT, RTYPE, R, C, E)
return
end

subroutine MPI_Gatherv(SBUF,SCNT,STYPE,RBUF,RCNT,DSP,RTYPE,R,C,E)
call MPIF_Gatherv(SBUF,SCNT,STYPE,RBUF,RCNT,DSP,RTYPE,R,C,E)
return
end

subroutine MPI_Scatter(SBUF,SCNT,STYPE,RBUF,RCNT,RTYPE,R,C,E)
call MPIF_Scatter(SBUF, SCNT, STYPE, RBUF, RCNT, RTYPE, R, C, E)
return
end

subroutine MPI_Scatterv(SBUF,SCNT,DSP,SDTYP,RBUF,RCNT,RTYP,R,C,E)
call  MPIF_Scatterv(SBUF,SCNT,DSP,STYP,RBUF, RCNT, RTYP, R, C, E)
return
end

subroutine MPI_Allgather(SBUF, SCNT, STYP, RBUF, RCNT, RTYP, C, E)
call MPIF_Allgather(SBUF, SCNT, STYP, RBUF, RCNT, RTYP, C, E)
return
end

subroutine MPI_Allgatherv(SB, SC, ST, RB, RC, D, RT, C, IERROR)
call MPIF_Allgatherv(SB, SC, ST, RB, RC, D, RT, C, IERROR)
return
end

subroutine MPI_Alltoall(SB, SC, ST, RB, RC, RT, COMM, IERROR)
call MPIF_Alltoall(SB, SC, ST, RB, RC, RT, COMM, IERROR)
return
end

subroutine MPI_Alltoallv(SB, SC, SD, ST, RB, RC, RD, RT, C, ERROR)
call MPIF_Alltoallv(SB, SC, SD, ST, RB, RC, RD, RT, C, ERROR)
return
end

subroutine MPI_Reduce(SBUF, RBUF, CNT, D, OP, ROOT, COMM, IERROR)
call MPIF_Reduce(SBUF, RBUF, CNT, D, OP, ROOT, COMM, IERROR)
return
end

subroutine MPI_Allreduce(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
call MPIF_Allreduce(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
return
end

subroutine MPI_Reduce_scatter(SBUF, RBUF, RCNT, D, OP, C, IERROR)
call MPIF_Reduce_scatter(SBUF, RBUF, RCNT, D, OP, C, IERROR)
return
end

subroutine MPI_Scan(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
call  MPIF_Scan(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
return
end

subroutine MPI_Send_init(B, C, T, D, TAG, COMM, R, IERROR)
call MPIF_Send_init(B, C, T, D, TAG, COMM, R, IERROR)
return
end

subroutine MPI_BSend_init(B, C, T, D, TAG, COMM, R, IERROR)
call MPIF_BSend_init(B, C, T, D, TAG, COMM, R, IERROR)
return
end

subroutine MPI_RSend_init(B, C, T, D, TAG, COMM, R, IERROR)
call MPIF_RSend_init(B, C, T, D, TAG, COMM, R, IERROR)
return
end

subroutine MPI_SSend_init(B, C, T, D, TAG, COMM, R, IERROR)
call MPIF_SSend_init(B, C, T, D, TAG, COMM, R, IERROR)
return
end

subroutine MPI_Recv_init(B, C, T, S, TAG, COMM, R, IERROR)
call MPIF_Recv_init(B, C, T, S, TAG, COMM, R, IERROR)
return
end

subroutine MPI_Start(R, IERROR)
call MPIF_Start(R, IERROR)
return
end

subroutine MPI_Startall(C, R, IERROR)
call MPIF_Startall(C, R, IERROR)
return
end

==> eztrace_0.9.1.orig.tar.gz: eztrace-0.9.1/src/modules/mpi/mpi_f.f90 <==
subroutine MPI_COMM_SPAWN(CMD, ARGV, M, I, R, C, INTERCOMM, A, E)
call MPIF_COMM_SPAWN(CMD, ARGV, M, I, R, C, INTERCOMM, A, E)
return
end

subroutine MPI_INIT(error)
call MPIF_INIT(error)
return
end

subroutine MPI_Init_thread(REQUIRED, PROVIDED, IERROR)
call MPIF_Init_thread(REQUIRED, PROVIDED, IERROR)
return
end

subroutine MPI_Finalize(IERROR)
call MPIF_Finalize(IERROR)
return
end

subroutine MPI_Barrier(COMM, IERROR)
call MPIF_Barrier(COMM, IERROR)
return
end

subroutine MPI_Comm_size(COMM, SIZE, IERROR)
call MPIF_Comm_size(COMM, SIZE, IERROR)
return
end

subroutine MPI_Comm_rank(COMM, RANK, IERROR)
call MPIF_Comm_rank(COMM, RANK, IERROR)
return
end

subroutine MPI_Send(BUF, COUNT, DATATYPE, DEST, TAG, COMM, IERROR)
call MPIF_Send(BUF, COUNT, DATATYPE, DEST, TAG, COMM, IERROR)
return
end

subroutine MPI_Recv(BUF, COUNT, D, SRC, TAG, COMM, STATUS, IERROR)
call MPIF_Recv(BUF, COUNT, D, SRC, TAG, COMM, STATUS, IERROR)
return
end

subroutine MPI_Sendecv(SBUF, SCOUNT, STYPE, DST, STAG, RBUF, RCOUNT, RTYPE, SRC, RTAG, COMM, STATUS, ERROR)
call MPIF_Sendrecv(SBUF, SCOUNT, STYPE, DST, STAG, RBUF, RCOUNT, RTYPE, SRC, RTAG, COMM, STATUS, ERROR)
return
end

subroutine MPI_Sendecv_replace(BUF, COUNT, TYPE, DST, STAG, SRC, RTAG, COMM, STATUS, ERROR)
call MPIF_Sendrecv_replace(BUF, COUNT, TYPE, DST, STAG, SRC, RTAG, COMM, STATUS, ERROR)
return
end

subroutine MPI_Bsend(BUF, COUNT,DATATYPE, DEST, TAG, COMM, IERROR)
call MPIF_Bsend(BUF, COUNT,DATATYPE, DEST, TAG, COMM, IERROR)
return
end

subroutine MPI_Ssend(BUF, COUNT, D, DEST, TAG, COMM, IERROR)
call MPIF_Ssend(BUF, COUNT, D, DEST, TAG, COMM, IERROR)
return
end

subroutine MPI_Rsend(BUF, COUNT, D, DEST, TAG, COMM, IERROR)
call MPIF_Rsend(BUF, COUNT, D, DEST, TAG, COMM, IERROR)
return
end

subroutine MPI_Isend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
call MPIF_Isend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Ibsend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
call MPIF_Ibsend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Issend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
call MPIF_Issend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Irsend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
call MPIF_Irsend(BUF, COUNT, D, DST, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Irecv(B, CNT, D, SRC, TAG, COMM, REQ, IERROR)
call MPIF_Irecv(B, CNT, D, SRC, TAG, COMM, REQ, IERROR)
return
end

subroutine MPI_Wait(REQUEST, STATUS, IERROR)
call MPIF_Wait(REQUEST, STATUS, IERROR)
return
end

subroutine MPI_WAITALL(COUNT, R, S, IERROR)
call MPIF_Waitall(COUNT, R, S, IERROR)
return
end

subroutine MPI_WAITANY(COUNT, R, S, INDEX, IERROR)
call MPIF_Waitany(COUNT, R, S, INDEX, IERROR)
return
end

subroutine MPI_WAITSOME(IC, R, OC, INDEX, S, IERROR)
call MPIF_Waitsome(IC, R, OC, INDEX, S, IERROR)
return
end

subroutine MPI_TESTSOME(IC, R, OC, INDEX, S, IERROR)
call MPIF_Testsome(IC, R, OC, INDEX, S, IERROR)
return
end


subroutine MPI_PROBE(S, T, C, STAT, IERROR)
call MPIF_PROBE(S, T, C, STAT, IERROR)
return
end

subroutine MPI_IPROBE(S, T, C, FLAG, STAT, IERROR)
call MPIF_IPROBE(S, T, C, FLAG, STAT, IERROR)
return
end


subroutine MPI_Test(REQUEST, FLAG, STATUS, IERROR)
call MPIF_Test(REQUEST, FLAG, STATUS, IERROR)
return
end

subroutine MPI_Testall(C, REQUEST, INDEX, STATUS, IERROR)
call MPIF_Testall(C, REQUEST, INDEX, STATUS, IERROR)
return
end

subroutine MPI_Testany(C, REQUEST, INDEX, F, STATUS, IERROR)
call MPIF_Testany(C, REQUEST, INDEX, F, STATUS, IERROR)
return
end

subroutine MPI_Get(O_A, O_C, O_D, T_R, T_DS, T_C, T_D, W, ERROR)
call MPIF_Get(O_A, O_C, O_D, T_R, T_DS, T_C, T_D, W, ERROR)
return
end

subroutine MPI_Put(O_A, O_C, O_D, T_R, T_DS, T_C, T_D, W, ERROR)
call MPIF_Put(O_A, O_C, O_D, T_R, T_DS, T_C, T_D, W, ERROR)
return
end

subroutine MPI_BCast(BUFFER, COUNT, DATATYPE, ROOT, COMM, IERROR)
call MPIF_BCast(BUFFER, COUNT, DATATYPE, ROOT, COMM, IERROR)
return
end

subroutine MPI_Gather(SBUF,SCNT,STYPE,RBUF,RCNT, RTYPE, R, C, E)
call MPIF_Gather(SBUF, SCNT, STYPE, RBUF, RCNT, RTYPE, R, C, E)
return
end

subroutine MPI_Gatherv(SBUF,SCNT,STYPE,RBUF,RCNT,DSP,RTYPE,R,C,E)
call MPIF_Gatherv(SBUF,SCNT,STYPE,RBUF,RCNT,DSP,RTYPE,R,C,E)
return
end

subroutine MPI_Scatter(SBUF,SCNT,STYPE,RBUF,RCNT,RTYPE,R,C,E)
call MPIF_Scatter(SBUF, SCNT, STYPE, RBUF, RCNT, RTYPE, R, C, E)
return
end

subroutine MPI_Scatterv(SBUF,SCNT,DSP,SDTYP,RBUF,RCNT,RTYP,R,C,E)
call  MPIF_Scatterv(SBUF,SCNT,DSP,STYP,RBUF, RCNT, RTYP, R, C, E)
return
end

subroutine MPI_Allgather(SBUF, SCNT, STYP, RBUF, RCNT, RTYP, C, E)
call MPIF_Allgather(SBUF, SCNT, STYP, RBUF, RCNT, RTYP, C, E)
return
end

subroutine MPI_Allgatherv(SB, SC, ST, RB, RC, D, RT, C, IERROR)
call MPIF_Allgatherv(SB, SC, ST, RB, RC, D, RT, C, IERROR)
return
end

subroutine MPI_Alltoall(SB, SC, ST, RB, RC, RT, COMM, IERROR)
call MPIF_Alltoall(SB, SC, ST, RB, RC, RT, COMM, IERROR)
return
end

subroutine MPI_Alltoallv(SB, SC, SD, ST, RB, RC, RD, RT, C, ERROR)
call MPIF_Alltoallv(SB, SC, SD, ST, RB, RC, RD, RT, C, ERROR)
return
end

subroutine MPI_Reduce(SBUF, RBUF, CNT, D, OP, ROOT, COMM, IERROR)
call MPIF_Reduce(SBUF, RBUF, CNT, D, OP, ROOT, COMM, IERROR)
return
end

subroutine MPI_Allreduce(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
call MPIF_Allreduce(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
return
end

subroutine MPI_Reduce_scatter(SBUF, RBUF, RCNT, D, OP, C, IERROR)
call MPIF_Reduce_scatter(SBUF, RBUF, RCNT, D, OP, C, IERROR)
return
end

subroutine MPI_Scan(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
call  MPIF_Scan(SBUF, RBUF, CNT, D, OP, COMM, IERROR)
return
end




subroutine MPI_IBarrier(COMM, REQ, IERROR)
call MPIF_IBarrier(COMM, REQ, IERROR)
return
end

subroutine MPI_IBCast(BUFFER, COUNT, DATATYPE, ROOT, COMM, REQ, IERROR)
call MPIF_IBCast(BUFFER, COUNT, DATATYPE, ROOT, COMM, REQ, IERROR)
return
end

subroutine MPI_IGather(SBUF,SCNT,STYPE,RBUF,RCNT, RTYPE, R, C, REQ, E)
call MPIF_IGather(SBUF, SCNT, STYPE, RBUF, RCNT, RTYPE, R, C, REQ, E)
return
end

subroutine MPI_IGatherv(SBUF,SCNT,STYPE,RBUF,RCNT,DSP,RTYPE,R,C,REQ,E)
call MPIF_IGatherv(SBUF,SCNT,STYPE,RBUF,RCNT,DSP,RTYPE,R,C,REQ,E)
return
end

subroutine MPI_IScatter(SBUF,SCNT,STYPE,RBUF,RCNT,RTYPE,R,C,REQ,E)
call MPIF_IScatter(SBUF, SCNT, STYPE, RBUF, RCNT, RTYPE, R, C,REQ, E)
return
end

subroutine MPI_IScatterv(SBUF,SCNT,DSP,SDTYP,RBUF,RCNT,RTYP,R,C,REQ,E)
call  MPIF_IScatterv(SBUF,SCNT,DSP,STYP,RBUF, RCNT, RTYP, R, C, REQ,E)
return
end

subroutine MPI_IAllgather(SBUF, SCNT, STYP, RBUF, RCNT, RTYP, C, REQ, E)
call MPIF_IAllgather(SBUF, SCNT, STYP, RBUF, RCNT, RTYP, C, REQ, E)
return
end

subroutine MPI_IAllgatherv(SB, SC, ST, RB, RC, D, RT, C, REQ,IERROR)
call MPIF_IAllgatherv(SB, SC, ST, RB, RC, D, RT, C, REQ,IERROR)
return
end

subroutine MPI_IAlltoall(SB, SC, ST, RB, RC, RT, COMM, REQ,IERROR)
call MPIF_IAlltoall(SB, SC, ST, RB, RC, RT, COMM, REQ,IERROR)
return
end

subroutine MPI_IAlltoallv(SB, SC, SD, ST, RB, RC, RD, RT, C, REQ,ERROR)
call MPIF_IAlltoallv(SB, SC, SD, ST, RB, RC, RD, RT, C, REQ,ERROR)
return
end

subroutine MPI_IReduce(SBUF, RBUF, CNT, D, OP, ROOT, COMM, REQ,IERROR)
call MPIF_IReduce(SBUF, RBUF, CNT, D, OP, ROOT, COMM, REQ,IERROR)
return
end

subroutine MPI_IAllreduce(SBUF, RBUF, CNT, D, OP, COMM, REQ,IERROR)
call MPIF_IAllreduce(SBUF, RBUF, CNT, D, OP, COMM, REQ,IERROR)
return
end

subroutine MPI_IReduce_scatter(SBUF, RBUF, RCNT, D, OP, C, REQ,IERROR)
call MPIF_IReduce_scatter(SBUF, RBUF, RCNT, D, OP, C, REQ,IERROR)
return
end

subroutine MPI_IScan(SBUF, RBUF, CNT, D, OP, COMM, REQ,IERROR)
call  MPIF_IScan(SBUF, RBUF, CNT, D, OP, COMM, REQ,IERROR)
return
end



subroutine MPI_Send_init(B, C, T, D, TAG, COMM, R, IERROR)
call MPIF_Send_init(B, C, T, D, TAG, COMM, R, IERROR)
return
end

subroutine MPI_BSend_init(B, C, T, D, TAG, COMM, R, IERROR)
call MPIF_BSend_init(B, C, T, D, TAG, COMM, R, IERROR)
return
end

subroutine MPI_RSend_init(B, C, T, D, TAG, COMM, R, IERROR)
call MPIF_RSend_init(B, C, T, D, TAG, COMM, R, IERROR)
return
end

subroutine MPI_SSend_init(B, C, T, D, TAG, COMM, R, IERROR)
call MPIF_SSend_init(B, C, T, D, TAG, COMM, R, IERROR)
return
end

subroutine MPI_Recv_init(B, C, T, S, TAG, COMM, R, IERROR)
call MPIF_Recv_init(B, C, T, S, TAG, COMM, R, IERROR)
return
end

subroutine MPI_Start(R, IERROR)
call MPIF_Start(R, IERROR)
return
end

subroutine MPI_Startall(C, R, IERROR)
call MPIF_Startall(C, R, IERROR)
return
end


subroutine MPI_Comm_create(comm, group, newcomm, IERROR)
call MPIF_Comm_create(comm, group, newcomm, IERROR)
return
end

subroutine MPI_Comm_split(comm, color, key, newcomm, IERROR)
call MPIF_Comm_split(comm, color, key, newcomm, IERROR)
return
end

subroutine MPI_Comm_dup(comm, newcomm, IERROR)
call MPIF_Comm_dup(comm, newcomm, IERROR)
return
end

subroutine MPI_Intercomm_create(local_comm, local_leader, peer_comm, remote_leader, tag, newintercomm, IERROR)
call MPIF_Intercomm_create(local_comm, local_leader, peer_comm, remote_leader, tag, newintercomm, IERROR)
return
end

subroutine MPI_Intercomm_merge(intercomm, high, newintracomm, IERROR)
call MPIF_Intercomm_merge(intercomm, high, newintracomm, IERROR)
return
end

subroutine MPI_Cart_sub(old_comm, belongs, new_comm, IERROR)
call MPIF_Cart_sub(old_comm, belongs, new_comm, IERROR)
return
end

subroutine MPI_Cart_create(comm_old, ndims, dims, periods, reorder, comm_cart, IERROR)
call MPIF_Cart_create(comm_old, ndims, dims, periods, reorder, comm_cart, IERROR)
return
end

subroutine MPI_Graph_create(comm_old, nnodes, index, edges, reorder, comm_graph, IERROR)
call MPIF_Graph_create(comm_old, nnodes, index, edges, reorder, comm_graph, IERROR)
return
end
